# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerStatementPredicate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'edge_label': 'str',
        'relation': 'str',
        'negated': 'bool'
    }

    attribute_map = {
        'edge_label': 'edge_label',
        'relation': 'relation',
        'negated': 'negated'
    }

    def __init__(self, edge_label=None, relation=None, negated=None):  # noqa: E501
        """ServerStatementPredicate - a model defined in Swagger"""  # noqa: E501

        self._edge_label = None
        self._relation = None
        self._negated = None
        self.discriminator = None

        if edge_label is not None:
            self.edge_label = edge_label
        if relation is not None:
            self.relation = relation
        if negated is not None:
            self.negated = negated

    @property
    def edge_label(self):
        """Gets the edge_label of this ServerStatementPredicate.  # noqa: E501

        The predicate edge label associated with this statement, which should be as published by the /predicates API endpoint and must be taken from the minimal predicate ('slot') list of the [Biolink Model](https://biolink.github.io/biolink-model).   # noqa: E501

        :return: The edge_label of this ServerStatementPredicate.  # noqa: E501
        :rtype: str
        """
        return self._edge_label

    @edge_label.setter
    def edge_label(self, edge_label):
        """Sets the edge_label of this ServerStatementPredicate.

        The predicate edge label associated with this statement, which should be as published by the /predicates API endpoint and must be taken from the minimal predicate ('slot') list of the [Biolink Model](https://biolink.github.io/biolink-model).   # noqa: E501

        :param edge_label: The edge_label of this ServerStatementPredicate.  # noqa: E501
        :type: str
        """

        self._edge_label = edge_label

    @property
    def relation(self):
        """Gets the relation of this ServerStatementPredicate.  # noqa: E501

        The predicate relation associated with this statement, which should be as published by the /predicates API endpoint with the preferred format being a CURIE where one exists, but strings/labels acceptable. This relation may be equivalent to the edge_label (e.g. edge_label: has_phenotype, relation: RO:0002200), or a more specific relation in cases where the source provides more granularity (e.g. edge_label: molecularly_interacts_with, relation: RO:0002447)  # noqa: E501

        :return: The relation of this ServerStatementPredicate.  # noqa: E501
        :rtype: str
        """
        return self._relation

    @relation.setter
    def relation(self, relation):
        """Sets the relation of this ServerStatementPredicate.

        The predicate relation associated with this statement, which should be as published by the /predicates API endpoint with the preferred format being a CURIE where one exists, but strings/labels acceptable. This relation may be equivalent to the edge_label (e.g. edge_label: has_phenotype, relation: RO:0002200), or a more specific relation in cases where the source provides more granularity (e.g. edge_label: molecularly_interacts_with, relation: RO:0002447)  # noqa: E501

        :param relation: The relation of this ServerStatementPredicate.  # noqa: E501
        :type: str
        """

        self._relation = relation

    @property
    def negated(self):
        """Gets the negated of this ServerStatementPredicate.  # noqa: E501

        (Optional) a boolean that if set to true, indicates the edge statement is negated i.e. is not true   # noqa: E501

        :return: The negated of this ServerStatementPredicate.  # noqa: E501
        :rtype: bool
        """
        return self._negated

    @negated.setter
    def negated(self, negated):
        """Sets the negated of this ServerStatementPredicate.

        (Optional) a boolean that if set to true, indicates the edge statement is negated i.e. is not true   # noqa: E501

        :param negated: The negated of this ServerStatementPredicate.  # noqa: E501
        :type: bool
        """

        self._negated = negated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementPredicate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
