# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kba
from kba.api.aggregator_api import AggregatorApi  # noqa: E501
from kba.rest import ApiException


class TestAggregatorApi(unittest.TestCase):
    """AggregatorApi unit test stubs"""

    def setUp(self):
        self.api = kba.api.aggregator_api.AggregatorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_beacons(self):
        """Test case for get_beacons

        """
        pass

    def test_get_concept_categories(self):
        """Test case for get_concept_categories

        """
        pass

    def test_get_error_log(self):
        """Test case for get_error_log

        """
        pass

    def test_get_knowledge_map(self):
        """Test case for get_knowledge_map

        """
        pass

    def test_get_predicates(self):
        """Test case for get_predicates

        """
        pass


if __name__ == '__main__':
    unittest.main()
