# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_knowledge_map_statement import ServerKnowledgeMapStatement  # noqa: F401,E501


class ServerKnowledgeMap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'statements': 'list[ServerKnowledgeMapStatement]'
    }

    attribute_map = {
        'beacon': 'beacon',
        'statements': 'statements'
    }

    def __init__(self, beacon=None, statements=None):  # noqa: E501
        """ServerKnowledgeMap - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._statements = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if statements is not None:
            self.statements = statements

    @property
    def beacon(self):
        """Gets the beacon of this ServerKnowledgeMap.  # noqa: E501

        aggregator assigned beacon index identifier   # noqa: E501

        :return: The beacon of this ServerKnowledgeMap.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerKnowledgeMap.

        aggregator assigned beacon index identifier   # noqa: E501

        :param beacon: The beacon of this ServerKnowledgeMap.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def statements(self):
        """Gets the statements of this ServerKnowledgeMap.  # noqa: E501


        :return: The statements of this ServerKnowledgeMap.  # noqa: E501
        :rtype: list[ServerKnowledgeMapStatement]
        """
        return self._statements

    @statements.setter
    def statements(self, statements):
        """Sets the statements of this ServerKnowledgeMap.


        :param statements: The statements of this ServerKnowledgeMap.  # noqa: E501
        :type: list[ServerKnowledgeMapStatement]
        """

        self._statements = statements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerKnowledgeMap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
